@@ -1473,10 +1473,16 @@
   (unused5
    macro-tgroup-unused5
    macro-tgroup-unused5-set!)
-  (threads-deq-next
+  (unused6
+   macro-tgroup-unused6
+   macro-tgroup-unused6-set!)
+  (unused7
+   macro-tgroup-unused7
+   macro-tgroup-unused7-set!)
+  (threads-deq-next ;; must be at same pos as the same name field in a thread
    macro-tgroup-threads-deq-next
    macro-tgroup-threads-deq-next-set!)
-  (threads-deq-prev
+  (threads-deq-prev ;; must be at same pos as the same name field in a thread
    macro-tgroup-threads-deq-prev
    macro-tgroup-threads-deq-prev-set!)
 )
@@ -1499,6 +1505,8 @@
               #f
               #f
               #f
+              #f
+              #f
               #f)))
        (macro-tgroup-tgroups-deq-init! tgroups)
        (macro-tgroup-threads-deq-init! tgroup)
